Developer documentation
=======================

This documentation is intended for other developers that would like to contribute with the development of pydap, 
or extend it in new ways. It assumes that you have a basic knowledge of Python and HTTP, and 
understands how data is stored in different formats. 
It also assumes some familiarity with the `Data Access Protocol <http://opendap.org/>`_, 
though a lot of its inner workings will be explained in detail here.

.. include:: developer_data_model.rst

.. include:: developer_handlers.rst

.. include:: developer_responses.rst

.. include:: developer_templating.rst
